# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.workspace_group_tree_node_dto import WorkspaceGroupTreeNodeDto

class TestWorkspaceGroupTreeNodeDto(unittest.TestCase):
    """WorkspaceGroupTreeNodeDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WorkspaceGroupTreeNodeDto:
        """Test WorkspaceGroupTreeNodeDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WorkspaceGroupTreeNodeDto`
        """
        model = WorkspaceGroupTreeNodeDto()
        if include_optional:
            return WorkspaceGroupTreeNodeDto(
                id = '',
                group = legit_api_client.models.workspace_group_dto.WorkspaceGroupDto(
                    id = '', 
                    name = '', 
                    description = '', ),
                integrations_count = 56,
                workspaces_count = 56,
                sub_groups = [
                    legit_api_client.models.workspace_group_tree_node_dto.WorkspaceGroupTreeNodeDto(
                        id = '', 
                        group = null, 
                        integrations_count = 56, 
                        workspaces_count = 56, 
                        sub_groups = [
                            legit_api_client.models.workspace_group_tree_node_dto.WorkspaceGroupTreeNodeDto(
                                id = '', 
                                group = null, 
                                integrations_count = 56, 
                                workspaces_count = 56, 
                                workspaces = [
                                    legit_api_client.models.workspace_tree_node_dto.WorkspaceTreeNodeDto(
                                        id = '', 
                                        workspace = null, 
                                        integrations_count = 56, )
                                    ], )
                            ], 
                        workspaces = [
                            legit_api_client.models.workspace_tree_node_dto.WorkspaceTreeNodeDto(
                                id = '', 
                                workspace = null, 
                                integrations_count = 56, )
                            ], )
                    ],
                workspaces = [
                    legit_api_client.models.workspace_tree_node_dto.WorkspaceTreeNodeDto(
                        id = '', 
                        workspace = null, 
                        integrations_count = 56, )
                    ]
            )
        else:
            return WorkspaceGroupTreeNodeDto(
        )
        """

    def testWorkspaceGroupTreeNodeDto(self):
        """Test WorkspaceGroupTreeNodeDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.create_workspace_group_dto import CreateWorkspaceGroupDto

class TestCreateWorkspaceGroupDto(unittest.TestCase):
    """CreateWorkspaceGroupDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateWorkspaceGroupDto:
        """Test CreateWorkspaceGroupDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateWorkspaceGroupDto`
        """
        model = CreateWorkspaceGroupDto()
        if include_optional:
            return CreateWorkspaceGroupDto(
                name = '',
                description = '',
                parent_group_id = '',
                child_group_ids = [
                    ''
                    ],
                child_workspace_ids = [
                    ''
                    ]
            )
        else:
            return CreateWorkspaceGroupDto(
        )
        """

    def testCreateWorkspaceGroupDto(self):
        """Test CreateWorkspaceGroupDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import apis into api package
from legit_api_client.api.amazon_ecr_key_integration_api import AmazonEcrKeyIntegrationApi
from legit_api_client.api.amazon_ecr_role_integration_api import AmazonEcrRoleIntegrationApi
from legit_api_client.api.brokers_api import BrokersApi
from legit_api_client.api.cloud_instances_api import CloudInstancesApi
from legit_api_client.api.collaborators_api import CollaboratorsApi
from legit_api_client.api.compliance_api import ComplianceApi
from legit_api_client.api.container_images_api import ContainerImagesApi
from legit_api_client.api.custom_fields_api import CustomFieldsApi
from legit_api_client.api.integrations_api import IntegrationsApi
from legit_api_client.api.issues_api import IssuesApi
from legit_api_client.api.issues_v2_api import IssuesV2Api
from legit_api_client.api.policies_api import PoliciesApi
from legit_api_client.api.product_units_api import ProductUnitsApi
from legit_api_client.api.repositories_api import RepositoriesApi
from legit_api_client.api.repository_groups_api import RepositoryGroupsApi
from legit_api_client.api.sdlc_assets_api import SDLCAssetsApi
from legit_api_client.api.saved_queries_api import SavedQueriesApi
from legit_api_client.api.tags_api import TagsApi
from legit_api_client.api.workspaces_api import WorkspacesApi




# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.legit_score_dto import LegitScoreDto

class TestLegitScoreDto(unittest.TestCase):
    """LegitScoreDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LegitScoreDto:
        """Test LegitScoreDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LegitScoreDto`
        """
        model = LegitScoreDto()
        if include_optional:
            return LegitScoreDto(
                id = '',
                score = 1.337,
                max_points = 1.337,
                gained_points = 1.337,
                categories = [
                    legit_api_client.models.legit_score_category_dto.LegitScoreCategoryDto(
                        type = null, 
                        max_points = 1.337, 
                        gained_points = 1.337, 
                        title = '', 
                        requirements = [
                            legit_api_client.models.legit_score_requirement_dto.LegitScoreRequirementDto(
                                type = null, 
                                max_points = 1.337, 
                                title = '', 
                                description = '', 
                                gained_points = 1.337, )
                            ], )
                    ],
                grade = 'APlus',
                score_out_of100 = 1.337
            )
        else:
            return LegitScoreDto(
        )
        """

    def testLegitScoreDto(self):
        """Test LegitScoreDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from legit_api_client.models.ai_validation_result import AiValidationResult
from legit_api_client.models.closing_reason import ClosingReason
from legit_api_client.models.customer_facing_issue_source_dto import CustomerFacingIssueSourceDto
from legit_api_client.models.dast_confidence_level import DastConfidenceLevel
from legit_api_client.models.dependency_fix_type import DependencyFixType
from legit_api_client.models.issue_closing_location_dto import IssueClosingLocationDto
from legit_api_client.models.issue_comment_dto import IssueCommentDto
from legit_api_client.models.issue_status import IssueStatus
from legit_api_client.models.issue_tag_dto import IssueTagDto
from legit_api_client.models.issue_type import IssueType
from legit_api_client.models.origin_type import OriginType
from legit_api_client.models.secret_issue_validity_status import SecretIssueValidityStatus
from legit_api_client.models.severity import Severity
from legit_api_client.models.snoozed_type import SnoozedType
from typing import Optional, Set
from typing_extensions import Self

class CustomerFacingIssueDto(BaseModel):
    """
    CustomerFacingIssueDto
    """ # noqa: E501
    id: Optional[StrictStr] = None
    title: Optional[StrictStr] = None
    detected_at: Optional[datetime] = Field(default=None, alias="detectedAt")
    last_closed_at: Optional[datetime] = Field(default=None, alias="lastClosedAt")
    last_action_time: Optional[datetime] = Field(default=None, alias="lastActionTime")
    status: Optional[IssueStatus] = None
    issue_type: Optional[IssueType] = Field(default=None, alias="issueType")
    severity: Optional[Severity] = None
    policy_severity: Optional[Severity] = Field(default=None, alias="policySeverity")
    closing_reason: Optional[ClosingReason] = Field(default=None, alias="closingReason")
    closing_location: Optional[IssueClosingLocationDto] = Field(default=None, alias="closingLocation")
    status_changed_note: Optional[StrictStr] = Field(default=None, alias="statusChangedNote")
    remediation_steps: Optional[List[StrictStr]] = Field(default=None, alias="remediationSteps")
    snoozed_type: Optional[SnoozedType] = Field(default=None, alias="snoozedType")
    snoozed_until: Optional[datetime] = Field(default=None, alias="snoozedUntil")
    score: Optional[Union[StrictFloat, StrictInt]] = None
    epss_score: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="epssScore")
    additional_data: Optional[Any] = Field(default=None, description="Additional specific data on the issue (fields can change from issue to issue). This data is not strictly structured and can be changed by legit at any time.", alias="additionalData")
    ai_validation_result: Optional[AiValidationResult] = Field(default=None, alias="aiValidationResult")
    dast_confidence_level: Optional[DastConfidenceLevel] = Field(default=None, alias="dastConfidenceLevel")
    validity_status: Optional[SecretIssueValidityStatus] = Field(default=None, alias="validityStatus")
    validity_check_time: Optional[datetime] = Field(default=None, alias="validityCheckTime")
    verified_validation_url: Optional[StrictStr] = Field(default=None, alias="verifiedValidationUrl")
    minimal_dependency_fix_type: Optional[DependencyFixType] = Field(default=None, alias="minimalDependencyFixType")
    sources: Optional[List[CustomerFacingIssueSourceDto]] = Field(default=None, description="The issue sources. May be omitted if data fetch fails - in this case please contact legit for support.")
    comments: Optional[List[IssueCommentDto]] = Field(default=None, description="Comments on the issue (can be an empty list). May be omitted if data fetch fails - in this case please contact legit for support.")
    tags: Optional[List[IssueTagDto]] = Field(default=None, description="Tags related to the issue (can be an empty list). May be omitted if data fetch fails - in this case please contact legit for support.")
    tickets: Optional[List[StrictStr]] = Field(default=None, description="Tickets related to the issue (can be an empty list). May be omitted if data fetch fails - in this case please contact legit for support.")
    origin_id: Optional[StrictStr] = Field(default=None, alias="originId")
    origin_type: Optional[OriginType] = Field(default=None, alias="originType")
    origin_link: Optional[StrictStr] = Field(default=None, description="A link to fetch the issue origin using the API", alias="originLink")
    action_id: Optional[StrictStr] = Field(default=None, description="The id of the Action that contains this issue", alias="actionId")
    policy_name: Optional[StrictStr] = Field(default=None, alias="policyName")
    product_ids: Optional[List[StrictStr]] = Field(default=None, alias="productIds")
    assigned_user_id: Optional[StrictStr] = Field(default=None, alias="assignedUserId")
    __properties: ClassVar[List[str]] = ["id", "title", "detectedAt", "lastClosedAt", "lastActionTime", "status", "issueType", "severity", "policySeverity", "closingReason", "closingLocation", "statusChangedNote", "remediationSteps", "snoozedType", "snoozedUntil", "score", "epssScore", "additionalData", "aiValidationResult", "dastConfidenceLevel", "validityStatus", "validityCheckTime", "verifiedValidationUrl", "minimalDependencyFixType", "sources", "comments", "tags", "tickets", "originId", "originType", "originLink", "actionId", "policyName", "productIds", "assignedUserId"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CustomerFacingIssueDto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "additional_data",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in sources (list)
        _items = []
        if self.sources:
            for _item_sources in self.sources:
                if _item_sources:
                    _items.append(_item_sources.to_dict())
            _dict['sources'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in comments (list)
        _items = []
        if self.comments:
            for _item_comments in self.comments:
                if _item_comments:
                    _items.append(_item_comments.to_dict())
            _dict['comments'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in tags (list)
        _items = []
        if self.tags:
            for _item_tags in self.tags:
                if _item_tags:
                    _items.append(_item_tags.to_dict())
            _dict['tags'] = _items
        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if title (nullable) is None
        # and model_fields_set contains the field
        if self.title is None and "title" in self.model_fields_set:
            _dict['title'] = None

        # set to None if last_closed_at (nullable) is None
        # and model_fields_set contains the field
        if self.last_closed_at is None and "last_closed_at" in self.model_fields_set:
            _dict['lastClosedAt'] = None

        # set to None if last_action_time (nullable) is None
        # and model_fields_set contains the field
        if self.last_action_time is None and "last_action_time" in self.model_fields_set:
            _dict['lastActionTime'] = None

        # set to None if closing_reason (nullable) is None
        # and model_fields_set contains the field
        if self.closing_reason is None and "closing_reason" in self.model_fields_set:
            _dict['closingReason'] = None

        # set to None if closing_location (nullable) is None
        # and model_fields_set contains the field
        if self.closing_location is None and "closing_location" in self.model_fields_set:
            _dict['closingLocation'] = None

        # set to None if status_changed_note (nullable) is None
        # and model_fields_set contains the field
        if self.status_changed_note is None and "status_changed_note" in self.model_fields_set:
            _dict['statusChangedNote'] = None

        # set to None if remediation_steps (nullable) is None
        # and model_fields_set contains the field
        if self.remediation_steps is None and "remediation_steps" in self.model_fields_set:
            _dict['remediationSteps'] = None

        # set to None if snoozed_type (nullable) is None
        # and model_fields_set contains the field
        if self.snoozed_type is None and "snoozed_type" in self.model_fields_set:
            _dict['snoozedType'] = None

        # set to None if snoozed_until (nullable) is None
        # and model_fields_set contains the field
        if self.snoozed_until is None and "snoozed_until" in self.model_fields_set:
            _dict['snoozedUntil'] = None

        # set to None if score (nullable) is None
        # and model_fields_set contains the field
        if self.score is None and "score" in self.model_fields_set:
            _dict['score'] = None

        # set to None if epss_score (nullable) is None
        # and model_fields_set contains the field
        if self.epss_score is None and "epss_score" in self.model_fields_set:
            _dict['epssScore'] = None

        # set to None if additional_data (nullable) is None
        # and model_fields_set contains the field
        if self.additional_data is None and "additional_data" in self.model_fields_set:
            _dict['additionalData'] = None

        # set to None if ai_validation_result (nullable) is None
        # and model_fields_set contains the field
        if self.ai_validation_result is None and "ai_validation_result" in self.model_fields_set:
            _dict['aiValidationResult'] = None

        # set to None if validity_check_time (nullable) is None
        # and model_fields_set contains the field
        if self.validity_check_time is None and "validity_check_time" in self.model_fields_set:
            _dict['validityCheckTime'] = None

        # set to None if verified_validation_url (nullable) is None
        # and model_fields_set contains the field
        if self.verified_validation_url is None and "verified_validation_url" in self.model_fields_set:
            _dict['verifiedValidationUrl'] = None

        # set to None if sources (nullable) is None
        # and model_fields_set contains the field
        if self.sources is None and "sources" in self.model_fields_set:
            _dict['sources'] = None

        # set to None if comments (nullable) is None
        # and model_fields_set contains the field
        if self.comments is None and "comments" in self.model_fields_set:
            _dict['comments'] = None

        # set to None if tags (nullable) is None
        # and model_fields_set contains the field
        if self.tags is None and "tags" in self.model_fields_set:
            _dict['tags'] = None

        # set to None if tickets (nullable) is None
        # and model_fields_set contains the field
        if self.tickets is None and "tickets" in self.model_fields_set:
            _dict['tickets'] = None

        # set to None if origin_id (nullable) is None
        # and model_fields_set contains the field
        if self.origin_id is None and "origin_id" in self.model_fields_set:
            _dict['originId'] = None

        # set to None if origin_link (nullable) is None
        # and model_fields_set contains the field
        if self.origin_link is None and "origin_link" in self.model_fields_set:
            _dict['originLink'] = None

        # set to None if action_id (nullable) is None
        # and model_fields_set contains the field
        if self.action_id is None and "action_id" in self.model_fields_set:
            _dict['actionId'] = None

        # set to None if policy_name (nullable) is None
        # and model_fields_set contains the field
        if self.policy_name is None and "policy_name" in self.model_fields_set:
            _dict['policyName'] = None

        # set to None if product_ids (nullable) is None
        # and model_fields_set contains the field
        if self.product_ids is None and "product_ids" in self.model_fields_set:
            _dict['productIds'] = None

        # set to None if assigned_user_id (nullable) is None
        # and model_fields_set contains the field
        if self.assigned_user_id is None and "assigned_user_id" in self.model_fields_set:
            _dict['assignedUserId'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CustomerFacingIssueDto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "title": obj.get("title"),
            "detectedAt": obj.get("detectedAt"),
            "lastClosedAt": obj.get("lastClosedAt"),
            "lastActionTime": obj.get("lastActionTime"),
            "status": obj.get("status"),
            "issueType": obj.get("issueType"),
            "severity": obj.get("severity"),
            "policySeverity": obj.get("policySeverity"),
            "closingReason": obj.get("closingReason"),
            "closingLocation": obj.get("closingLocation"),
            "statusChangedNote": obj.get("statusChangedNote"),
            "remediationSteps": obj.get("remediationSteps"),
            "snoozedType": obj.get("snoozedType"),
            "snoozedUntil": obj.get("snoozedUntil"),
            "score": obj.get("score"),
            "epssScore": obj.get("epssScore"),
            "additionalData": obj.get("additionalData"),
            "aiValidationResult": obj.get("aiValidationResult"),
            "dastConfidenceLevel": obj.get("dastConfidenceLevel"),
            "validityStatus": obj.get("validityStatus"),
            "validityCheckTime": obj.get("validityCheckTime"),
            "verifiedValidationUrl": obj.get("verifiedValidationUrl"),
            "minimalDependencyFixType": obj.get("minimalDependencyFixType"),
            "sources": [CustomerFacingIssueSourceDto.from_dict(_item) for _item in obj["sources"]] if obj.get("sources") is not None else None,
            "comments": [IssueCommentDto.from_dict(_item) for _item in obj["comments"]] if obj.get("comments") is not None else None,
            "tags": [IssueTagDto.from_dict(_item) for _item in obj["tags"]] if obj.get("tags") is not None else None,
            "tickets": obj.get("tickets"),
            "originId": obj.get("originId"),
            "originType": obj.get("originType"),
            "originLink": obj.get("originLink"),
            "actionId": obj.get("actionId"),
            "policyName": obj.get("policyName"),
            "productIds": obj.get("productIds"),
            "assignedUserId": obj.get("assignedUserId")
        })
        return _obj





# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.cloud_instances_to_containers_operation_dto import CloudInstancesToContainersOperationDto

class TestCloudInstancesToContainersOperationDto(unittest.TestCase):
    """CloudInstancesToContainersOperationDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CloudInstancesToContainersOperationDto:
        """Test CloudInstancesToContainersOperationDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CloudInstancesToContainersOperationDto`
        """
        model = CloudInstancesToContainersOperationDto()
        if include_optional:
            return CloudInstancesToContainersOperationDto(
                attach = legit_api_client.models.container_to_cloud_resource_operation_dto.ContainerToCloudResourceOperationDto(
                    container_ids = [
                        ''
                        ], 
                    cloud_resource_ids = [
                        ''
                        ], ),
                detach = legit_api_client.models.container_to_cloud_resource_operation_dto.ContainerToCloudResourceOperationDto(
                    container_ids = [
                        ''
                        ], 
                    cloud_resource_ids = [
                        ''
                        ], )
            )
        else:
            return CloudInstancesToContainersOperationDto(
        )
        """

    def testCloudInstancesToContainersOperationDto(self):
        """Test CloudInstancesToContainersOperationDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.customer_facing_issues_page_dto import CustomerFacingIssuesPageDto

class TestCustomerFacingIssuesPageDto(unittest.TestCase):
    """CustomerFacingIssuesPageDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CustomerFacingIssuesPageDto:
        """Test CustomerFacingIssuesPageDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CustomerFacingIssuesPageDto`
        """
        model = CustomerFacingIssuesPageDto()
        if include_optional:
            return CustomerFacingIssuesPageDto(
                items = [
                    legit_api_client.models.basic_issue.BasicIssue(
                        issue_type = null, 
                        severity = null, 
                        id = '', )
                    ],
                next_token = ''
            )
        else:
            return CustomerFacingIssuesPageDto(
        )
        """

    def testCustomerFacingIssuesPageDto(self):
        """Test CustomerFacingIssuesPageDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ControlSourceType(str, Enum):
    """
    ControlSourceType
    """

    """
    allowed enum values
    """
    WORKFLOWJOB = 'WorkflowJob'
    CONFIGURATION = 'Configuration'
    JENKINS = 'Jenkins'
    LEGIT = 'Legit'
    PERMANENT = 'Permanent'
    DETECTEDPIPELINESTEP = 'DetectedPipelineStep'
    SNYKINTEGRATION = 'SnykIntegration'
    SONARCLOUDINTEGRATION = 'SonarCloudIntegration'
    SONARQUBEINTEGRATION = 'SonarQubeIntegration'
    SHIFTLEFTINTEGRATION = 'ShiftLeftIntegration'
    BLACKDUCKINTEGRATION = 'BlackDuckIntegration'
    VERACODEINTEGRATION = 'VeracodeIntegration'
    DETECTEDPULLREQUESTCHECK = 'DetectedPullRequestCheck'
    SONATYPEINTEGRATION = 'SonatypeIntegration'
    CHECKMARXSASTINTEGRATION = 'CheckmarxSastIntegration'
    CHECKMARXSCAINTEGRATION = 'CheckmarxScaIntegration'
    MENDSCAINTEGRATION = 'MendScaIntegration'
    MENDSASTINTEGRATION = 'MendSastIntegration'
    SEMGREPINTEGRATION = 'SemgrepIntegration'
    COVERITYINTEGRATION = 'CoverityIntegration'
    CHECKMARXONEINTEGRATION = 'CheckmarxOneIntegration'
    FORTIFYINTEGRATION = 'FortifyIntegration'
    HCLAPPSCANINTEGRATION = 'HclAppScanIntegration'
    NOWSECUREINTEGRATION = 'NowSecureIntegration'
    ONAPSISINTEGRATION = 'OnapsisIntegration'
    QUOKKAQMASTINTEGRATION = 'QuokkaQMastIntegration'
    CONTRASTSECURITYINTEGRATION = 'ContrastSecurityIntegration'
    ENDORLABSSCAINTEGRATION = 'EndorLabsScaIntegration'
    XRAYINTEGRATION = 'XrayIntegration'
    BURPSUITEINTEGRATION = 'BurpsuiteIntegration'
    INVICTIINTEGRATION = 'InvictiIntegration'
    QUALYSINTEGRATION = 'QualysIntegration'
    NONAMEINTEGRATION = 'NonameIntegration'
    TRACEABLEINTEGRATION = 'TraceableIntegration'
    AMAZONINSPECTORINTEGRATION = 'AmazonInspectorIntegration'
    OLIGOINTEGRATION = 'OligoIntegration'
    ACUNETIXINTEGRATION = 'AcunetixIntegration'
    MENDINTEGRATION = 'MendIntegration'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ControlSourceType from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.api.integrations_api import IntegrationsApi


class TestIntegrationsApi(unittest.TestCase):
    """IntegrationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IntegrationsApi()

    def tearDown(self) -> None:
        pass

    def test_api_v10_integrations_amazon_ecr_key_id_put(self) -> None:
        """Test case for api_v10_integrations_amazon_ecr_key_id_put

        Update Amazon ECR Key integration
        """
        pass

    def test_api_v10_integrations_amazon_ecr_key_post(self) -> None:
        """Test case for api_v10_integrations_amazon_ecr_key_post

        Create Amazon ECR key integration
        """
        pass

    def test_api_v10_integrations_amazon_ecr_role_id_put(self) -> None:
        """Test case for api_v10_integrations_amazon_ecr_role_id_put

        Update Amazon ECR Role integration
        """
        pass

    def test_api_v10_integrations_amazon_ecr_role_post(self) -> None:
        """Test case for api_v10_integrations_amazon_ecr_role_post

        Create Amazon ECR Role integration
        """
        pass

    def test_api_v10_integrations_azure_acr_id_delete(self) -> None:
        """Test case for api_v10_integrations_azure_acr_id_delete

        Delete Azure ACR integration by Id
        """
        pass

    def test_api_v10_integrations_azure_acr_id_put(self) -> None:
        """Test case for api_v10_integrations_azure_acr_id_put

        Update Azure GCR integration
        """
        pass

    def test_api_v10_integrations_azure_acr_post(self) -> None:
        """Test case for api_v10_integrations_azure_acr_post

        Create Azure ACR integration
        """
        pass

    def test_api_v10_integrations_get(self) -> None:
        """Test case for api_v10_integrations_get

        Get all integrations
        """
        pass

    def test_api_v10_integrations_google_gcr_id_delete(self) -> None:
        """Test case for api_v10_integrations_google_gcr_id_delete

        Delete Google GCR integration by Id
        """
        pass

    def test_api_v10_integrations_google_gcr_id_put(self) -> None:
        """Test case for api_v10_integrations_google_gcr_id_put

        Update Google GCR integration
        """
        pass

    def test_api_v10_integrations_google_gcr_post(self) -> None:
        """Test case for api_v10_integrations_google_gcr_post

        Create Google GCR integration
        """
        pass

    def test_api_v10_integrations_id_delete(self) -> None:
        """Test case for api_v10_integrations_id_delete

        Delete integration by id
        """
        pass

    def test_api_v10_integrations_id_get(self) -> None:
        """Test case for api_v10_integrations_id_get

        Get integration by id
        """
        pass

    def test_api_v10_integrations_jenkins_id_delete(self) -> None:
        """Test case for api_v10_integrations_jenkins_id_delete

        Delete Jenkins integration by Id
        """
        pass

    def test_api_v10_integrations_jenkins_id_put(self) -> None:
        """Test case for api_v10_integrations_jenkins_id_put

        Update Jenkins integration
        """
        pass

    def test_api_v10_integrations_jenkins_post(self) -> None:
        """Test case for api_v10_integrations_jenkins_post

        Create Jenkins integration
        """
        pass

    def test_api_v10_integrations_workspace_bulk_post(self) -> None:
        """Test case for api_v10_integrations_workspace_bulk_post

        Apply bulk workspace operation
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class LegitScoreRequirementGroupType(str, Enum):
    """
    LegitScoreRequirementGroupType
    """

    """
    allowed enum values
    """
    MISCONFIGURATIONS = 'Misconfigurations'
    PIPELINE = 'Pipeline'
    CODEHYGIENE = 'CodeHygiene'
    INCIDENTS = 'Incidents'
    CONTROLS = 'Controls'
    CLOUDMISCONFIGURATION = 'CloudMisconfiguration'
    INTEGRATIONACCOUNT = 'IntegrationAccount'
    INTEGRATIONCOLLABORATION = 'IntegrationCollaboration'
    SAST = 'Sast'
    SCA = 'Sca'
    ISSUES = 'Issues'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LegitScoreRequirementGroupType from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from legit_api_client.models.business_impact import BusinessImpact
from legit_api_client.models.product_tree_node_dto import ProductTreeNodeDto
from legit_api_client.models.product_unit_dto_custom_fields_value import ProductUnitDtoCustomFieldsValue
from legit_api_client.models.product_unit_environment import ProductUnitEnvironment
from legit_api_client.models.product_unit_type import ProductUnitType
from typing import Optional, Set
from typing_extensions import Self

class ProductUnitDto(BaseModel):
    """
    ProductUnitDto
    """ # noqa: E501
    id: Optional[StrictStr] = None
    type: Optional[ProductUnitType] = None
    workspace_id: Optional[StrictStr] = Field(default=None, alias="workspaceId")
    score: Optional[Union[StrictFloat, StrictInt]] = None
    repositories_count: Optional[StrictInt] = Field(default=None, alias="repositoriesCount")
    environment: Optional[ProductUnitEnvironment] = None
    description: Optional[StrictStr] = None
    security_champion_id: Optional[StrictStr] = Field(default=None, alias="securityChampionId")
    business_impact: Optional[BusinessImpact] = Field(default=None, alias="businessImpact")
    issues_count: Optional[StrictInt] = Field(default=None, alias="issuesCount")
    name: Optional[StrictStr] = None
    score_out_of100: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="scoreOutOf100")
    score_goal: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="scoreGoal")
    nested_product_units: Optional[List[ProductTreeNodeDto]] = Field(default=None, alias="nestedProductUnits")
    custom_fields: Optional[Dict[str, Optional[ProductUnitDtoCustomFieldsValue]]] = Field(default=None, alias="customFields")
    __properties: ClassVar[List[str]] = ["id", "type", "workspaceId", "score", "repositoriesCount", "environment", "description", "securityChampionId", "businessImpact", "issuesCount", "name", "scoreOutOf100", "scoreGoal", "nestedProductUnits", "customFields"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ProductUnitDto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "score_out_of100",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in nested_product_units (list)
        _items = []
        if self.nested_product_units:
            for _item_nested_product_units in self.nested_product_units:
                if _item_nested_product_units:
                    _items.append(_item_nested_product_units.to_dict())
            _dict['nestedProductUnits'] = _items
        # override the default output from pydantic by calling `to_dict()` of each value in custom_fields (dict)
        _field_dict = {}
        if self.custom_fields:
            for _key_custom_fields in self.custom_fields:
                if self.custom_fields[_key_custom_fields]:
                    _field_dict[_key_custom_fields] = self.custom_fields[_key_custom_fields].to_dict()
            _dict['customFields'] = _field_dict
        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if workspace_id (nullable) is None
        # and model_fields_set contains the field
        if self.workspace_id is None and "workspace_id" in self.model_fields_set:
            _dict['workspaceId'] = None

        # set to None if score (nullable) is None
        # and model_fields_set contains the field
        if self.score is None and "score" in self.model_fields_set:
            _dict['score'] = None

        # set to None if repositories_count (nullable) is None
        # and model_fields_set contains the field
        if self.repositories_count is None and "repositories_count" in self.model_fields_set:
            _dict['repositoriesCount'] = None

        # set to None if environment (nullable) is None
        # and model_fields_set contains the field
        if self.environment is None and "environment" in self.model_fields_set:
            _dict['environment'] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if security_champion_id (nullable) is None
        # and model_fields_set contains the field
        if self.security_champion_id is None and "security_champion_id" in self.model_fields_set:
            _dict['securityChampionId'] = None

        # set to None if business_impact (nullable) is None
        # and model_fields_set contains the field
        if self.business_impact is None and "business_impact" in self.model_fields_set:
            _dict['businessImpact'] = None

        # set to None if issues_count (nullable) is None
        # and model_fields_set contains the field
        if self.issues_count is None and "issues_count" in self.model_fields_set:
            _dict['issuesCount'] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if score_out_of100 (nullable) is None
        # and model_fields_set contains the field
        if self.score_out_of100 is None and "score_out_of100" in self.model_fields_set:
            _dict['scoreOutOf100'] = None

        # set to None if score_goal (nullable) is None
        # and model_fields_set contains the field
        if self.score_goal is None and "score_goal" in self.model_fields_set:
            _dict['scoreGoal'] = None

        # set to None if nested_product_units (nullable) is None
        # and model_fields_set contains the field
        if self.nested_product_units is None and "nested_product_units" in self.model_fields_set:
            _dict['nestedProductUnits'] = None

        # set to None if custom_fields (nullable) is None
        # and model_fields_set contains the field
        if self.custom_fields is None and "custom_fields" in self.model_fields_set:
            _dict['customFields'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ProductUnitDto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "type": obj.get("type"),
            "workspaceId": obj.get("workspaceId"),
            "score": obj.get("score"),
            "repositoriesCount": obj.get("repositoriesCount"),
            "environment": obj.get("environment"),
            "description": obj.get("description"),
            "securityChampionId": obj.get("securityChampionId"),
            "businessImpact": obj.get("businessImpact"),
            "issuesCount": obj.get("issuesCount"),
            "name": obj.get("name"),
            "scoreOutOf100": obj.get("scoreOutOf100"),
            "scoreGoal": obj.get("scoreGoal"),
            "nestedProductUnits": [ProductTreeNodeDto.from_dict(_item) for _item in obj["nestedProductUnits"]] if obj.get("nestedProductUnits") is not None else None,
            "customFields": dict(
                (_k, ProductUnitDtoCustomFieldsValue.from_dict(_v))
                for _k, _v in obj["customFields"].items()
            )
            if obj.get("customFields") is not None
            else None
        })
        return _obj





# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.sdlc_asset_graph_link_dto_evidences import SdlcAssetGraphLinkDtoEvidences

class TestSdlcAssetGraphLinkDtoEvidences(unittest.TestCase):
    """SdlcAssetGraphLinkDtoEvidences unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SdlcAssetGraphLinkDtoEvidences:
        """Test SdlcAssetGraphLinkDtoEvidences
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SdlcAssetGraphLinkDtoEvidences`
        """
        model = SdlcAssetGraphLinkDtoEvidences()
        if include_optional:
            return SdlcAssetGraphLinkDtoEvidences(
                unknown = [
                    ''
                    ],
                file = [
                    ''
                    ],
                webhook = [
                    ''
                    ],
                config = [
                    ''
                    ],
                job_config = [
                    ''
                    ],
                third_party_app = [
                    ''
                    ],
                organization_webhook = [
                    ''
                    ],
                correlated_artifact = [
                    ''
                    ],
                git_lab_repository_to_registry = [
                    ''
                    ],
                manual_correlation = [
                    ''
                    ],
                llm_based_correlation = [
                    ''
                    ]
            )
        else:
            return SdlcAssetGraphLinkDtoEvidences(
        )
        """

    def testSdlcAssetGraphLinkDtoEvidences(self):
        """Test SdlcAssetGraphLinkDtoEvidences"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.product_tree_node_dto import ProductTreeNodeDto

class TestProductTreeNodeDto(unittest.TestCase):
    """ProductTreeNodeDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ProductTreeNodeDto:
        """Test ProductTreeNodeDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ProductTreeNodeDto`
        """
        model = ProductTreeNodeDto()
        if include_optional:
            return ProductTreeNodeDto(
                name = '',
                type = 'Other',
                id = '',
                children = [
                    legit_api_client.models.product_tree_node_dto.ProductTreeNodeDto(
                        name = '', 
                        type = null, 
                        id = '', 
                        children = [
                            legit_api_client.models.product_tree_node_dto.ProductTreeNodeDto(
                                name = '', 
                                type = null, 
                                id = '', )
                            ], )
                    ]
            )
        else:
            return ProductTreeNodeDto(
        )
        """

    def testProductTreeNodeDto(self):
        """Test ProductTreeNodeDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictStr
from typing import Any, List, Optional
from typing_extensions import Annotated
from legit_api_client.models.discovered_sdlc_asset_dto import DiscoveredSdlcAssetDto
from legit_api_client.models.get_sdlc_asset_graph_evidence_by_ids_response_dto import GetSdlcAssetGraphEvidenceByIdsResponseDto
from legit_api_client.models.sdlc_asset_graph_dto import SdlcAssetGraphDto

from legit_api_client.api_client import ApiClient, RequestSerialized
from legit_api_client.api_response import ApiResponse
from legit_api_client.rest import RESTResponseType


class SDLCAssetsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def api_v10_sdlc_assets_discovered_get(
        self,
        sort_column: Optional[StrictStr] = None,
        sort_direction: Optional[Any] = None,
        can_be_integrated: Optional[StrictBool] = None,
        page_number: Optional[Annotated[int, Field(le=2147483647, strict=True, ge=1)]] = None,
        page_size: Optional[Annotated[int, Field(le=100, strict=True, ge=1)]] = None,
        search: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[DiscoveredSdlcAssetDto]:
        """Get all discovered SDLC assets


        :param sort_column:
        :type sort_column: str
        :param sort_direction:
        :type sort_direction: ListSortDirection
        :param can_be_integrated:
        :type can_be_integrated: bool
        :param page_number:
        :type page_number: int
        :param page_size:
        :type page_size: int
        :param search:
        :type search: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v10_sdlc_assets_discovered_get_serialize(
            sort_column=sort_column,
            sort_direction=sort_direction,
            can_be_integrated=can_be_integrated,
            page_number=page_number,
            page_size=page_size,
            search=search,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[DiscoveredSdlcAssetDto]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v10_sdlc_assets_discovered_get_with_http_info(
        self,
        sort_column: Optional[StrictStr] = None,
        sort_direction: Optional[Any] = None,
        can_be_integrated: Optional[StrictBool] = None,
        page_number: Optional[Annotated[int, Field(le=2147483647, strict=True, ge=1)]] = None,
        page_size: Optional[Annotated[int, Field(le=100, strict=True, ge=1)]] = None,
        search: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[DiscoveredSdlcAssetDto]]:
        """Get all discovered SDLC assets


        :param sort_column:
        :type sort_column: str
        :param sort_direction:
        :type sort_direction: ListSortDirection
        :param can_be_integrated:
        :type can_be_integrated: bool
        :param page_number:
        :type page_number: int
        :param page_size:
        :type page_size: int
        :param search:
        :type search: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v10_sdlc_assets_discovered_get_serialize(
            sort_column=sort_column,
            sort_direction=sort_direction,
            can_be_integrated=can_be_integrated,
            page_number=page_number,
            page_size=page_size,
            search=search,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[DiscoveredSdlcAssetDto]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v10_sdlc_assets_discovered_get_without_preload_content(
        self,
        sort_column: Optional[StrictStr] = None,
        sort_direction: Optional[Any] = None,
        can_be_integrated: Optional[StrictBool] = None,
        page_number: Optional[Annotated[int, Field(le=2147483647, strict=True, ge=1)]] = None,
        page_size: Optional[Annotated[int, Field(le=100, strict=True, ge=1)]] = None,
        search: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get all discovered SDLC assets


        :param sort_column:
        :type sort_column: str
        :param sort_direction:
        :type sort_direction: ListSortDirection
        :param can_be_integrated:
        :type can_be_integrated: bool
        :param page_number:
        :type page_number: int
        :param page_size:
        :type page_size: int
        :param search:
        :type search: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v10_sdlc_assets_discovered_get_serialize(
            sort_column=sort_column,
            sort_direction=sort_direction,
            can_be_integrated=can_be_integrated,
            page_number=page_number,
            page_size=page_size,
            search=search,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[DiscoveredSdlcAssetDto]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v10_sdlc_assets_discovered_get_serialize(
        self,
        sort_column,
        sort_direction,
        can_be_integrated,
        page_number,
        page_size,
        search,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if sort_column is not None:
            
            _query_params.append(('sortColumn', sort_column))
            
        if sort_direction is not None:
            
            _query_params.append(('sortDirection', sort_direction.value))
            
        if can_be_integrated is not None:
            
            _query_params.append(('canBeIntegrated', can_be_integrated))
            
        if page_number is not None:
            
            _query_params.append(('pageNumber', page_number))
            
        if page_size is not None:
            
            _query_params.append(('pageSize', page_size))
            
        if search is not None:
            
            _query_params.append(('search', search))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'text/plain', 
                    'application/json', 
                    'text/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1.0/sdlc-assets/discovered',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v10_sdlc_assets_graph_evidence_by_ids_get(
        self,
        evidence_ids: Optional[List[StrictStr]] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GetSdlcAssetGraphEvidenceByIdsResponseDto:
        """Get SDLC asset graph evidence by Ids


        :param evidence_ids:
        :type evidence_ids: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v10_sdlc_assets_graph_evidence_by_ids_get_serialize(
            evidence_ids=evidence_ids,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetSdlcAssetGraphEvidenceByIdsResponseDto",
            '400': "ProblemDetails",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v10_sdlc_assets_graph_evidence_by_ids_get_with_http_info(
        self,
        evidence_ids: Optional[List[StrictStr]] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GetSdlcAssetGraphEvidenceByIdsResponseDto]:
        """Get SDLC asset graph evidence by Ids


        :param evidence_ids:
        :type evidence_ids: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v10_sdlc_assets_graph_evidence_by_ids_get_serialize(
            evidence_ids=evidence_ids,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetSdlcAssetGraphEvidenceByIdsResponseDto",
            '400': "ProblemDetails",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v10_sdlc_assets_graph_evidence_by_ids_get_without_preload_content(
        self,
        evidence_ids: Optional[List[StrictStr]] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get SDLC asset graph evidence by Ids


        :param evidence_ids:
        :type evidence_ids: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v10_sdlc_assets_graph_evidence_by_ids_get_serialize(
            evidence_ids=evidence_ids,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetSdlcAssetGraphEvidenceByIdsResponseDto",
            '400': "ProblemDetails",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v10_sdlc_assets_graph_evidence_by_ids_get_serialize(
        self,
        evidence_ids,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'evidenceIds': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if evidence_ids is not None:
            
            _query_params.append(('evidenceIds', evidence_ids))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'text/plain', 
                    'application/json', 
                    'text/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1.0/sdlc-assets/graph/evidence/by-ids',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v10_sdlc_assets_graph_get(
        self,
        show_only_integrated: Optional[StrictBool] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SdlcAssetGraphDto:
        """Get SDLC asset graph

        Each node in the graph is returned as an object in the `Assets` array. It is uniquely identified by the attributes `Id` and `Type`.  The edges are represented by the `Links` array. The source of each link is `SourceId` and `SourceType`. The target of each link is `TargetId` and `TargetType`.  The `IntegrationId` is not enough to identify a node, because it may apply to several nodes on the graph is some cases. For example is GitHub is used both as SCM and CI (GitHub Actions).  The Graph returned by this endpoint is more detailed than the Discovery Graph on the Legit Platform. When viewing the graph on the Legit Platform some nodes are aggregated into a single node (for example - all Amazon ECRs are displayed as a single node on the Legit Platform).

        :param show_only_integrated:
        :type show_only_integrated: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v10_sdlc_assets_graph_get_serialize(
            show_only_integrated=show_only_integrated,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SdlcAssetGraphDto",
            '400': "ProblemDetails",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v10_sdlc_assets_graph_get_with_http_info(
        self,
        show_only_integrated: Optional[StrictBool] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[SdlcAssetGraphDto]:
        """Get SDLC asset graph

        Each node in the graph is returned as an object in the `Assets` array. It is uniquely identified by the attributes `Id` and `Type`.  The edges are represented by the `Links` array. The source of each link is `SourceId` and `SourceType`. The target of each link is `TargetId` and `TargetType`.  The `IntegrationId` is not enough to identify a node, because it may apply to several nodes on the graph is some cases. For example is GitHub is used both as SCM and CI (GitHub Actions).  The Graph returned by this endpoint is more detailed than the Discovery Graph on the Legit Platform. When viewing the graph on the Legit Platform some nodes are aggregated into a single node (for example - all Amazon ECRs are displayed as a single node on the Legit Platform).

        :param show_only_integrated:
        :type show_only_integrated: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v10_sdlc_assets_graph_get_serialize(
            show_only_integrated=show_only_integrated,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SdlcAssetGraphDto",
            '400': "ProblemDetails",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v10_sdlc_assets_graph_get_without_preload_content(
        self,
        show_only_integrated: Optional[StrictBool] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get SDLC asset graph

        Each node in the graph is returned as an object in the `Assets` array. It is uniquely identified by the attributes `Id` and `Type`.  The edges are represented by the `Links` array. The source of each link is `SourceId` and `SourceType`. The target of each link is `TargetId` and `TargetType`.  The `IntegrationId` is not enough to identify a node, because it may apply to several nodes on the graph is some cases. For example is GitHub is used both as SCM and CI (GitHub Actions).  The Graph returned by this endpoint is more detailed than the Discovery Graph on the Legit Platform. When viewing the graph on the Legit Platform some nodes are aggregated into a single node (for example - all Amazon ECRs are displayed as a single node on the Legit Platform).

        :param show_only_integrated:
        :type show_only_integrated: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v10_sdlc_assets_graph_get_serialize(
            show_only_integrated=show_only_integrated,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SdlcAssetGraphDto",
            '400': "ProblemDetails",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v10_sdlc_assets_graph_get_serialize(
        self,
        show_only_integrated,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if show_only_integrated is not None:
            
            _query_params.append(('showOnlyIntegrated', show_only_integrated))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'text/plain', 
                    'application/json', 
                    'text/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1.0/sdlc-assets/graph',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.api.policies_api import PoliciesApi


class TestPoliciesApi(unittest.TestCase):
    """PoliciesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PoliciesApi()

    def tearDown(self) -> None:
        pass

    def test_api_v10_policies_get(self) -> None:
        """Test case for api_v10_policies_get

        Get Policies
        """
        pass

    def test_get_policy_by_id(self) -> None:
        """Test case for get_policy_by_id

        Get Policy by id
        """
        pass

    def test_get_policy_by_name(self) -> None:
        """Test case for get_policy_by_name

        Get by Policy name
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ControlClassification(str, Enum):
    """
    ControlClassification
    """

    """
    allowed enum values
    """
    UNKNOWN = 'Unknown'
    SNYK = 'Snyk'
    SONARQUBE = 'SonarQube'
    TRAVISCI = 'TravisCi'
    WEBHINT = 'WebHint'
    LIGHTHOUSE = 'Lighthouse'
    SHIFTLEFT = 'ShiftLeft'
    TRUFFLEHOG = 'TruffleHog'
    GITLABSAST = 'GitLabSast'
    GITLABDAST = 'GitLabDast'
    GITLABCODEQUALITY = 'GitLabCodeQuality'
    GITLABCONTAINERSCANNING = 'GitLabContainerScanning'
    GITLABSECRETDETECTION = 'GitLabSecretDetection'
    GITLABDEPENDENCYSCANNING = 'GitLabDependencyScanning'
    GITLABLICENSESCANNING = 'GitLabLicenseScanning'
    DUSTICOCODEANALYZER = 'DusticoCodeAnalyzer'
    DUSTICODUSTILOCK = 'DusticoDustiLock'
    CODEREVIEW = 'CodeReview'
    DEPENDABOT = 'Dependabot'
    SOURCEGUARDDEPENDENCYSCANNING = 'SourceGuardDependencyScanning'
    SOURCEGUARDCONTAINERSCANNING = 'SourceGuardContainerScanning'
    VERACODE = 'Veracode'
    LEGITSECRETSCANNING = 'LegitSecretScanning'
    ADVANCEDSECURITYCODESCANNING = 'AdvancedSecurityCodeScanning'
    ADVANCEDSECURITYSECRETSCANNING = 'AdvancedSecuritySecretScanning'
    ADVANCEDSECURITYDEPENDENCYREVIEW = 'AdvancedSecurityDependencyReview'
    SONARCLOUD = 'SonarCloud'
    CYCODESECRETSCANNING = 'CycodeSecretScanning'
    E2ETESTS = 'E2ETests'
    LEGITIACSCANNING = 'LegitIacScanning'
    LEGITPIPELINESCANNING = 'LegitPipelineScanning'
    ATLASSIANGITSECRETSSCANNER = 'AtlassianGitSecretsScanner'
    FOSSA = 'Fossa'
    PRISMACLOUDTWISTLOCK = 'PrismaCloudTwistlock'
    SNYKSCA = 'SnykSca'
    SNYKSAST = 'SnykSast'
    BLACKDUCK = 'BlackDuck'
    CHECKMARXSAST = 'CheckmarxSast'
    CROWDSTRIKE = 'CrowdStrike'
    LEGITSCASCANNING = 'LegitScaScanning'
    SONATYPE = 'Sonatype'
    WIZ = 'Wiz'
    MENDSCA = 'MendSca'
    MENDSAST = 'MendSast'
    CHECKMARXSCA = 'CheckmarxSca'
    ENDORLABSSCA = 'EndorLabsSca'
    SEMGREP = 'Semgrep'
    SEMGREPSCA = 'SemgrepSca'
    COVERITYSAST = 'CoveritySast'
    CHECKMARXONESCA = 'CheckmarxOneSca'
    CHECKMARXONESAST = 'CheckmarxOneSast'
    FORTIFYSAST = 'FortifySast'
    HCLAPPSCANSAST = 'HclAppScanSast'
    HCLAPPSCANSCA = 'HclAppScanSca'
    NOWSECURESAST = 'NowSecureSast'
    ONAPSISSAST = 'OnapsisSast'
    ONAPSISSCA = 'OnapsisSca'
    QUOKKAQMASTSAST = 'QuokkaQMastSast'
    CONTRASTSECURITYSAST = 'ContrastSecuritySast'
    CONTRASTSECURITYSCA = 'ContrastSecuritySca'
    XRAY = 'Xray'
    AQUA = 'Aqua'
    MANUALUPLOAD = 'ManualUpload'
    BURPSUITE = 'Burpsuite'
    INVICTI = 'Invicti'
    QUALYS = 'Qualys'
    NONAME = 'Noname'
    TRACEABLE = 'Traceable'
    AMAZONINSPECTOR = 'AmazonInspector'
    OLIGO = 'Oligo'
    LEGITSASTSCANNING = 'LegitSastScanning'
    ORCA = 'Orca'
    UPWIND = 'Upwind'
    ACUNETIX = 'Acunetix'
    MEND = 'Mend'
    REDHATADVANCEDCLUSTERSECURITY = 'RedHatAdvancedClusterSecurity'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ControlClassification from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.compliance_criteria_dto import ComplianceCriteriaDto

class TestComplianceCriteriaDto(unittest.TestCase):
    """ComplianceCriteriaDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ComplianceCriteriaDto:
        """Test ComplianceCriteriaDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ComplianceCriteriaDto`
        """
        model = ComplianceCriteriaDto()
        if include_optional:
            return ComplianceCriteriaDto(
                id = '',
                sub_criterias = [
                    legit_api_client.models.compliance_criteria_dto.ComplianceCriteriaDto(
                        id = '', 
                        sub_criterias = [
                            legit_api_client.models.compliance_criteria_dto.ComplianceCriteriaDto(
                                id = '', 
                                criteria_name = '', 
                                title = '', 
                                requirements = [
                                    legit_api_client.models.compliance_requirement_dto.ComplianceRequirementDto(
                                        id = '', 
                                        requirement_name = '', 
                                        title = '', 
                                        description = '', 
                                        manual_checks = [
                                            legit_api_client.models.manual_check_dto.ManualCheckDto(
                                                id = '', 
                                                name = '', )
                                            ], 
                                        automatic_checks = [
                                            legit_api_client.models.automatic_check_dto.AutomaticCheckDto(
                                                id = '', 
                                                policy_name = '', 
                                                title = '', 
                                                category = '', 
                                                type = null, )
                                            ], )
                                    ], )
                            ], 
                        criteria_name = '', 
                        title = '', 
                        requirements = [
                            legit_api_client.models.compliance_requirement_dto.ComplianceRequirementDto(
                                id = '', 
                                requirement_name = '', 
                                title = '', 
                                description = '', )
                            ], )
                    ],
                criteria_name = '',
                title = '',
                requirements = [
                    legit_api_client.models.compliance_requirement_dto.ComplianceRequirementDto(
                        id = '', 
                        requirement_name = '', 
                        title = '', 
                        description = '', 
                        manual_checks = [
                            legit_api_client.models.manual_check_dto.ManualCheckDto(
                                id = '', 
                                name = '', )
                            ], 
                        automatic_checks = [
                            legit_api_client.models.automatic_check_dto.AutomaticCheckDto(
                                id = '', 
                                policy_name = '', 
                                title = '', 
                                category = '', 
                                type = null, )
                            ], )
                    ]
            )
        else:
            return ComplianceCriteriaDto(
        )
        """

    def testComplianceCriteriaDto(self):
        """Test ComplianceCriteriaDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from legit_api_client.models.add_issue_comment_dto import AddIssueCommentDto
from legit_api_client.models.ai_validation_result import AiValidationResult
from legit_api_client.models.amazon_ecr_key_integration_create_dto import AmazonEcrKeyIntegrationCreateDto
from legit_api_client.models.amazon_ecr_key_integration_edit_dto import AmazonEcrKeyIntegrationEditDto
from legit_api_client.models.amazon_ecr_role_integration_create_dto import AmazonEcrRoleIntegrationCreateDto
from legit_api_client.models.amazon_ecr_role_integration_edit_dto import AmazonEcrRoleIntegrationEditDto
from legit_api_client.models.apply_bulk_workspace_operation_dto import ApplyBulkWorkspaceOperationDto
from legit_api_client.models.apply_bulk_workspace_roles_operation_dto import ApplyBulkWorkspaceRolesOperationDto
from legit_api_client.models.asset_connection_dto import AssetConnectionDto
from legit_api_client.models.automatic_check_dto import AutomaticCheckDto
from legit_api_client.models.aws_region import AwsRegion
from legit_api_client.models.azure_container_registry_integration_create_dto import AzureContainerRegistryIntegrationCreateDto
from legit_api_client.models.azure_container_registry_integration_edit_dto import AzureContainerRegistryIntegrationEditDto
from legit_api_client.models.basic_issue import BasicIssue
from legit_api_client.models.broker_connection_status import BrokerConnectionStatus
from legit_api_client.models.broker_dto import BrokerDto
from legit_api_client.models.broker_status import BrokerStatus
from legit_api_client.models.business_impact import BusinessImpact
from legit_api_client.models.category import Category
from legit_api_client.models.closing_reason import ClosingReason
from legit_api_client.models.cloud_instance_dto import CloudInstanceDto
from legit_api_client.models.cloud_instances_to_containers_operation_dto import CloudInstancesToContainersOperationDto
from legit_api_client.models.collaborator_dto import CollaboratorDto
from legit_api_client.models.collaborator_repository_permission import CollaboratorRepositoryPermission
from legit_api_client.models.compliance_criteria_dto import ComplianceCriteriaDto
from legit_api_client.models.compliance_dto import ComplianceDto
from legit_api_client.models.compliance_report_dto import ComplianceReportDto
from legit_api_client.models.compliance_report_integration_dto import ComplianceReportIntegrationDto
from legit_api_client.models.compliance_report_request_dto import ComplianceReportRequestDto
from legit_api_client.models.compliance_report_requirement_dto import ComplianceReportRequirementDto
from legit_api_client.models.compliance_report_workspace_dto import ComplianceReportWorkspaceDto
from legit_api_client.models.compliance_requirement_dto import ComplianceRequirementDto
from legit_api_client.models.compliance_with_criterias_dto import ComplianceWithCriteriasDto
from legit_api_client.models.container_image_dto import ContainerImageDto
from legit_api_client.models.container_image_version_dto import ContainerImageVersionDto
from legit_api_client.models.container_to_cloud_resource_operation_dto import ContainerToCloudResourceOperationDto
from legit_api_client.models.container_to_repository_operation_dto import ContainerToRepositoryOperationDto
from legit_api_client.models.control_classification import ControlClassification
from legit_api_client.models.control_source_type import ControlSourceType
from legit_api_client.models.control_type import ControlType
from legit_api_client.models.correlated_cloud_instance import CorrelatedCloudInstance
from legit_api_client.models.correlated_repository_dto import CorrelatedRepositoryDto
from legit_api_client.models.create_automatic_check_dto import CreateAutomaticCheckDto
from legit_api_client.models.create_issues_tag_dto import CreateIssuesTagDto
from legit_api_client.models.create_product_unit_bad_request_dto import CreateProductUnitBadRequestDto
from legit_api_client.models.create_product_unit_dto import CreateProductUnitDto
from legit_api_client.models.create_tag_dto import CreateTagDto
from legit_api_client.models.create_workspace_dto import CreateWorkspaceDto
from legit_api_client.models.create_workspace_group_dto import CreateWorkspaceGroupDto
from legit_api_client.models.custom_field_bool_type_dto import CustomFieldBoolTypeDto
from legit_api_client.models.custom_field_date_type_dto import CustomFieldDateTypeDto
from legit_api_client.models.custom_field_dto import CustomFieldDto
from legit_api_client.models.custom_field_dto_type import CustomFieldDtoType
from legit_api_client.models.custom_field_entity import CustomFieldEntity
from legit_api_client.models.custom_field_file_type_dto import CustomFieldFileTypeDto
from legit_api_client.models.custom_field_identity_type_dto import CustomFieldIdentityTypeDto
from legit_api_client.models.custom_field_number_type_dto import CustomFieldNumberTypeDto
from legit_api_client.models.custom_field_text_type_dto import CustomFieldTextTypeDto
from legit_api_client.models.custom_field_type import CustomFieldType
from legit_api_client.models.customer_facing_issue_dto import CustomerFacingIssueDto
from legit_api_client.models.customer_facing_issue_source_dto import CustomerFacingIssueSourceDto
from legit_api_client.models.customer_facing_issues_page_dto import CustomerFacingIssuesPageDto
from legit_api_client.models.dast_confidence_level import DastConfidenceLevel
from legit_api_client.models.dependency_fix_type import DependencyFixType
from legit_api_client.models.detailed_sdlc_asset_information_dto import DetailedSdlcAssetInformationDto
from legit_api_client.models.discovered_sdlc_asset_dto import DiscoveredSdlcAssetDto
from legit_api_client.models.discovery_connection_evidence_type import DiscoveryConnectionEvidenceType
from legit_api_client.models.framework_policy_type import FrameworkPolicyType
from legit_api_client.models.get_custom_fields_response_dto import GetCustomFieldsResponseDto
from legit_api_client.models.get_sdlc_asset_graph_evidence_by_ids_response_dto import GetSdlcAssetGraphEvidenceByIdsResponseDto
from legit_api_client.models.google_container_registry_integration_create_dto import GoogleContainerRegistryIntegrationCreateDto
from legit_api_client.models.google_container_registry_integration_edit_dto import GoogleContainerRegistryIntegrationEditDto
from legit_api_client.models.integration_bad_response_dto import IntegrationBadResponseDto
from legit_api_client.models.integration_dto import IntegrationDto
from legit_api_client.models.integration_error import IntegrationError
from legit_api_client.models.integration_failing_reason import IntegrationFailingReason
from legit_api_client.models.integration_management_dto import IntegrationManagementDto
from legit_api_client.models.integration_status import IntegrationStatus
from legit_api_client.models.integration_type import IntegrationType
from legit_api_client.models.issue_assignment import IssueAssignment
from legit_api_client.models.issue_closing_location_dto import IssueClosingLocationDto
from legit_api_client.models.issue_comment_dto import IssueCommentDto
from legit_api_client.models.issue_count_by_severity_dto import IssueCountBySeverityDto
from legit_api_client.models.issue_dto import IssueDto
from legit_api_client.models.issue_ignoring_reason_dto import IssueIgnoringReasonDto
from legit_api_client.models.issue_opening_reason_dto import IssueOpeningReasonDto
from legit_api_client.models.issue_origin_dto import IssueOriginDto
from legit_api_client.models.issue_origin_params import IssueOriginParams
from legit_api_client.models.issue_sorting_column import IssueSortingColumn
from legit_api_client.models.issue_status import IssueStatus
from legit_api_client.models.issue_tag_dto import IssueTagDto
from legit_api_client.models.issue_ticketing_dto import IssueTicketingDto
from legit_api_client.models.issue_type import IssueType
from legit_api_client.models.issues_tag_dto import IssuesTagDto
from legit_api_client.models.jenkins_integration_create_dto import JenkinsIntegrationCreateDto
from legit_api_client.models.jenkins_integration_edit_dto import JenkinsIntegrationEditDto
from legit_api_client.models.legit_score_category_dto import LegitScoreCategoryDto
from legit_api_client.models.legit_score_dto import LegitScoreDto
from legit_api_client.models.legit_score_grade import LegitScoreGrade
from legit_api_client.models.legit_score_requirement_dto import LegitScoreRequirementDto
from legit_api_client.models.legit_score_requirement_group_type import LegitScoreRequirementGroupType
from legit_api_client.models.legit_score_requirement_type import LegitScoreRequirementType
from legit_api_client.models.list_sort_direction import ListSortDirection
from legit_api_client.models.manual_check_dto import ManualCheckDto
from legit_api_client.models.origin_type import OriginType
from legit_api_client.models.patch_legit_issue_assignee_dto import PatchLegitIssueAssigneeDto
from legit_api_client.models.patch_legit_issue_status_dto import PatchLegitIssueStatusDto
from legit_api_client.models.patch_legit_issue_unified_status_dto import PatchLegitIssueUnifiedStatusDto
from legit_api_client.models.patch_legit_issues_status_dto import PatchLegitIssuesStatusDto
from legit_api_client.models.patch_product_unit_custom_field_by_name import PatchProductUnitCustomFieldByName
from legit_api_client.models.patch_product_unit_custom_field_dto import PatchProductUnitCustomFieldDto
from legit_api_client.models.patch_product_unit_custom_fields_by_name_dto import PatchProductUnitCustomFieldsByNameDto
from legit_api_client.models.patch_product_unit_custom_fields_dto import PatchProductUnitCustomFieldsDto
from legit_api_client.models.patch_product_unit_dto import PatchProductUnitDto
from legit_api_client.models.patch_security_champion_id_dto import PatchSecurityChampionIdDto
from legit_api_client.models.permission_meta_type import PermissionMetaType
from legit_api_client.models.policy_dto import PolicyDto
from legit_api_client.models.problem_details import ProblemDetails
from legit_api_client.models.product_connection_type import ProductConnectionType
from legit_api_client.models.product_tree_node_dto import ProductTreeNodeDto
from legit_api_client.models.product_unit_asset_dto import ProductUnitAssetDto
from legit_api_client.models.product_unit_dto import ProductUnitDto
from legit_api_client.models.product_unit_dto_custom_fields_value import ProductUnitDtoCustomFieldsValue
from legit_api_client.models.product_unit_environment import ProductUnitEnvironment
from legit_api_client.models.product_unit_name_dto import ProductUnitNameDto
from legit_api_client.models.product_unit_type import ProductUnitType
from legit_api_client.models.repositories_to_containers_operation_dto import RepositoriesToContainersOperationDto
from legit_api_client.models.repository_control_dto import RepositoryControlDto
from legit_api_client.models.repository_directory import RepositoryDirectory
from legit_api_client.models.repository_dto import RepositoryDto
from legit_api_client.models.repository_group_dto import RepositoryGroupDto
from legit_api_client.models.repository_visibility import RepositoryVisibility
from legit_api_client.models.scm_type import ScmType
from legit_api_client.models.sdlc_asset_dto import SdlcAssetDto
from legit_api_client.models.sdlc_asset_graph_asset_dto import SdlcAssetGraphAssetDto
from legit_api_client.models.sdlc_asset_graph_dto import SdlcAssetGraphDto
from legit_api_client.models.sdlc_asset_graph_evidence_dto import SdlcAssetGraphEvidenceDto
from legit_api_client.models.sdlc_asset_graph_link_dto import SdlcAssetGraphLinkDto
from legit_api_client.models.sdlc_asset_graph_link_dto_evidences import SdlcAssetGraphLinkDtoEvidences
from legit_api_client.models.sdlc_asset_meta_type import SdlcAssetMetaType
from legit_api_client.models.sdlc_asset_type import SdlcAssetType
from legit_api_client.models.secret_issue_validity_status import SecretIssueValidityStatus
from legit_api_client.models.severity import Severity
from legit_api_client.models.snoozed_type import SnoozedType
from legit_api_client.models.tag_dto import TagDto
from legit_api_client.models.tag_source import TagSource
from legit_api_client.models.user_dto import UserDto
from legit_api_client.models.user_permission import UserPermission
from legit_api_client.models.user_role import UserRole
from legit_api_client.models.workspace_created_dto import WorkspaceCreatedDto
from legit_api_client.models.workspace_dto import WorkspaceDto
from legit_api_client.models.workspace_group_dto import WorkspaceGroupDto
from legit_api_client.models.workspace_group_tree_node_dto import WorkspaceGroupTreeNodeDto
from legit_api_client.models.workspace_hierarchy_dto import WorkspaceHierarchyDto
from legit_api_client.models.workspace_tree_node_dto import WorkspaceTreeNodeDto
from legit_api_client.models.workspace_type import WorkspaceType



# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class AwsRegion(str, Enum):
    """
    AwsRegion
    """

    """
    allowed enum values
    """
    USEAST2 = 'UsEast2'
    USEAST1 = 'UsEast1'
    USWEST1 = 'UsWest1'
    USWEST2 = 'UsWest2'
    AFSOUTH1 = 'AfSouth1'
    APEAST1 = 'ApEast1'
    APSOUTH2 = 'ApSouth2'
    APSOUTHEAST3 = 'ApSoutheast3'
    APSOUTH1 = 'ApSouth1'
    APNORTHEAST3 = 'ApNortheast3'
    APNORTHEAST2 = 'ApNortheast2'
    APSOUTHEAST1 = 'ApSoutheast1'
    APSOUTHEAST2 = 'ApSoutheast2'
    APNORTHEAST1 = 'ApNortheast1'
    CACENTRAL1 = 'CaCentral1'
    EUCENTRAL1 = 'EuCentral1'
    EUWEST1 = 'EuWest1'
    EUWEST2 = 'EuWest2'
    EUSOUTH1 = 'EuSouth1'
    EUWEST3 = 'EuWest3'
    EUSOUTH2 = 'EuSouth2'
    EUNORTH1 = 'EuNorth1'
    EUCENTRAL2 = 'EuCentral2'
    MESOUTH1 = 'MeSouth1'
    MECENTRAL1 = 'MeCentral1'
    SAEAST1 = 'SaEast1'
    USGOVEAST1 = 'UsGovEast1'
    USGOVWEST1 = 'UsGovWest1'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of AwsRegion from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from legit_api_client.models.product_unit_type import ProductUnitType
from legit_api_client.models.repository_directory import RepositoryDirectory
from typing import Optional, Set
from typing_extensions import Self

class CreateProductUnitDto(BaseModel):
    """
    CreateProductUnitDto
    """ # noqa: E501
    name: Annotated[str, Field(min_length=1, strict=True)]
    description: Optional[StrictStr] = None
    workspace_id: Optional[StrictStr] = Field(default=None, alias="workspaceId")
    type: Optional[ProductUnitType] = None
    repository_ids: Optional[List[StrictStr]] = Field(default=None, alias="repositoryIds")
    repository_group_ids: Optional[List[StrictStr]] = Field(default=None, alias="repositoryGroupIds")
    integration_ids: Optional[List[StrictStr]] = Field(default=None, alias="integrationIds")
    repository_directories: Optional[List[RepositoryDirectory]] = Field(default=None, alias="repositoryDirectories")
    nested_product_ids: Optional[List[StrictStr]] = Field(default=None, alias="nestedProductIds")
    __properties: ClassVar[List[str]] = ["name", "description", "workspaceId", "type", "repositoryIds", "repositoryGroupIds", "integrationIds", "repositoryDirectories", "nestedProductIds"]

    @field_validator('name')
    def name_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[\w\s!@#$%\^&*()={}:;<>+\'-\/]{1,60}$", value):
            raise ValueError(r"must validate the regular expression /^[\w\s!@#$%\^&*()={}:;<>+'-\/]{1,60}$/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CreateProductUnitDto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in repository_directories (list)
        _items = []
        if self.repository_directories:
            for _item_repository_directories in self.repository_directories:
                if _item_repository_directories:
                    _items.append(_item_repository_directories.to_dict())
            _dict['repositoryDirectories'] = _items
        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if workspace_id (nullable) is None
        # and model_fields_set contains the field
        if self.workspace_id is None and "workspace_id" in self.model_fields_set:
            _dict['workspaceId'] = None

        # set to None if repository_ids (nullable) is None
        # and model_fields_set contains the field
        if self.repository_ids is None and "repository_ids" in self.model_fields_set:
            _dict['repositoryIds'] = None

        # set to None if repository_group_ids (nullable) is None
        # and model_fields_set contains the field
        if self.repository_group_ids is None and "repository_group_ids" in self.model_fields_set:
            _dict['repositoryGroupIds'] = None

        # set to None if integration_ids (nullable) is None
        # and model_fields_set contains the field
        if self.integration_ids is None and "integration_ids" in self.model_fields_set:
            _dict['integrationIds'] = None

        # set to None if repository_directories (nullable) is None
        # and model_fields_set contains the field
        if self.repository_directories is None and "repository_directories" in self.model_fields_set:
            _dict['repositoryDirectories'] = None

        # set to None if nested_product_ids (nullable) is None
        # and model_fields_set contains the field
        if self.nested_product_ids is None and "nested_product_ids" in self.model_fields_set:
            _dict['nestedProductIds'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CreateProductUnitDto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "description": obj.get("description"),
            "workspaceId": obj.get("workspaceId"),
            "type": obj.get("type"),
            "repositoryIds": obj.get("repositoryIds"),
            "repositoryGroupIds": obj.get("repositoryGroupIds"),
            "integrationIds": obj.get("integrationIds"),
            "repositoryDirectories": [RepositoryDirectory.from_dict(_item) for _item in obj["repositoryDirectories"]] if obj.get("repositoryDirectories") is not None else None,
            "nestedProductIds": obj.get("nestedProductIds")
        })
        return _obj





# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.compliance_report_dto import ComplianceReportDto

class TestComplianceReportDto(unittest.TestCase):
    """ComplianceReportDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ComplianceReportDto:
        """Test ComplianceReportDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ComplianceReportDto`
        """
        model = ComplianceReportDto()
        if include_optional:
            return ComplianceReportDto(
                workspaces = [
                    legit_api_client.models.compliance_report_workspace_dto.ComplianceReportWorkspaceDto(
                        id = '', 
                        name = '', )
                    ],
                integrations = [
                    legit_api_client.models.compliance_report_integration_dto.ComplianceReportIntegrationDto(
                        id = '', 
                        name = '', 
                        integration_type = '', )
                    ],
                requirements = [
                    legit_api_client.models.compliance_report_requirement_dto.ComplianceReportRequirementDto(
                        policy = '', 
                        policy_name = '', 
                        criteria = '', 
                        sub_criteria = '', 
                        requirement = '', 
                        passed = True, 
                        evaluation_started = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        evaluation_ended = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ]
            )
        else:
            return ComplianceReportDto(
        )
        """

    def testComplianceReportDto(self):
        """Test ComplianceReportDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ProductConnectionType(str, Enum):
    """
    ProductConnectionType
    """

    """
    allowed enum values
    """
    REPOSITORY = 'Repository'
    REPOSITORYGROUP = 'RepositoryGroup'
    INTEGRATION = 'Integration'
    REPOSITORYNAMESUBSTRING = 'RepositoryNameSubstring'
    REPOSITORYCONFIGURATIONFILE = 'RepositoryConfigurationFile'
    REPOSITORYQUERY = 'RepositoryQuery'
    REPOSITORYDIRECTORY = 'RepositoryDirectory'
    REPOSITORYCOLLABORATOR = 'RepositoryCollaborator'
    REPOSITORYCONTAINER = 'RepositoryContainer'
    WEBAPPLICATION = 'WebApplication'
    WEBAPPLICATIONQUERY = 'WebApplicationQuery'
    CONTAINER = 'Container'
    CONTAINERQUERY = 'ContainerQuery'
    COLLABORATOR = 'Collaborator'
    COLLABORATORQUERY = 'CollaboratorQuery'
    APPSECPROJECT = 'AppSecProject'
    APPSECPROJECTQUERY = 'AppSecProjectQuery'
    AGGREGATEDHOST = 'AggregatedHost'
    CLOUDCOMPUTERESOURCEQUERY = 'CloudComputeResourceQuery'
    CLOUDCOMPUTERESOURCE = 'CloudComputeResource'
    NESTEDPRODUCTREPOSITORY = 'NestedProductRepository'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ProductConnectionType from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.api.workspaces_api import WorkspacesApi


class TestWorkspacesApi(unittest.TestCase):
    """WorkspacesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = WorkspacesApi()

    def tearDown(self) -> None:
        pass

    def test_api_v10_workspaces_get(self) -> None:
        """Test case for api_v10_workspaces_get

        Get all workspaces
        """
        pass

    def test_api_v10_workspaces_group_post(self) -> None:
        """Test case for api_v10_workspaces_group_post

        Create new workspace group
        """
        pass

    def test_api_v10_workspaces_hierarchy_get(self) -> None:
        """Test case for api_v10_workspaces_hierarchy_get

        Get workspace hierarchy
        """
        pass

    def test_api_v10_workspaces_id_delete(self) -> None:
        """Test case for api_v10_workspaces_id_delete

        Delete workspace
        """
        pass

    def test_api_v10_workspaces_id_get(self) -> None:
        """Test case for api_v10_workspaces_id_get

        Get workspace by id
        """
        pass

    def test_api_v10_workspaces_permissions_post(self) -> None:
        """Test case for api_v10_workspaces_permissions_post

        Add permissions to workspace/group
        """
        pass

    def test_api_v10_workspaces_post(self) -> None:
        """Test case for api_v10_workspaces_post

        Create new workspace
        """
        pass

    def test_api_v10_workspaces_workspace_id_integrations_get(self) -> None:
        """Test case for api_v10_workspaces_workspace_id_integrations_get

        Get integrations by workspace id
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.compliance_requirement_dto import ComplianceRequirementDto

class TestComplianceRequirementDto(unittest.TestCase):
    """ComplianceRequirementDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ComplianceRequirementDto:
        """Test ComplianceRequirementDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ComplianceRequirementDto`
        """
        model = ComplianceRequirementDto()
        if include_optional:
            return ComplianceRequirementDto(
                id = '',
                requirement_name = '',
                title = '',
                description = '',
                manual_checks = [
                    legit_api_client.models.manual_check_dto.ManualCheckDto(
                        id = '', 
                        name = '', )
                    ],
                automatic_checks = [
                    legit_api_client.models.automatic_check_dto.AutomaticCheckDto(
                        id = '', 
                        policy_name = '', 
                        title = '', 
                        category = '', 
                        type = null, )
                    ]
            )
        else:
            return ComplianceRequirementDto(
        )
        """

    def testComplianceRequirementDto(self):
        """Test ComplianceRequirementDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from legit_api_client.models.ai_validation_result import AiValidationResult
from legit_api_client.models.dast_confidence_level import DastConfidenceLevel
from legit_api_client.models.dependency_fix_type import DependencyFixType
from legit_api_client.models.integration_dto import IntegrationDto
from legit_api_client.models.issue_closing_location_dto import IssueClosingLocationDto
from legit_api_client.models.issue_comment_dto import IssueCommentDto
from legit_api_client.models.issue_ignoring_reason_dto import IssueIgnoringReasonDto
from legit_api_client.models.issue_origin_dto import IssueOriginDto
from legit_api_client.models.issue_status import IssueStatus
from legit_api_client.models.issue_tag_dto import IssueTagDto
from legit_api_client.models.issue_ticketing_dto import IssueTicketingDto
from legit_api_client.models.issue_type import IssueType
from legit_api_client.models.secret_issue_validity_status import SecretIssueValidityStatus
from legit_api_client.models.severity import Severity
from legit_api_client.models.snoozed_type import SnoozedType
from legit_api_client.models.user_dto import UserDto
from typing import Optional, Set
from typing_extensions import Self

class IssueDto(BaseModel):
    """
    IssueDto
    """ # noqa: E501
    id: Optional[StrictStr] = None
    policy_name: Optional[StrictStr] = Field(default=None, alias="policyName")
    title: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    related_action_id: Optional[StrictStr] = Field(default=None, alias="relatedActionId")
    origin: Optional[IssueOriginDto] = None
    ticketing: Optional[IssueTicketingDto] = None
    product_units: Optional[List[StrictStr]] = Field(default=None, alias="productUnits")
    detected_at: Optional[datetime] = Field(default=None, alias="detectedAt")
    last_closed_at: Optional[datetime] = Field(default=None, alias="lastClosedAt")
    status: Optional[IssueStatus] = None
    type: Optional[IssueType] = None
    severity: Optional[Severity] = None
    policy_severity: Optional[Severity] = Field(default=None, alias="policySeverity")
    payload: Optional[Any] = None
    integration: Optional[IntegrationDto] = None
    score: Optional[Union[StrictFloat, StrictInt]] = None
    epss_score: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="epssScore")
    assigned_user: Optional[UserDto] = Field(default=None, alias="assignedUser")
    comments: Optional[List[IssueCommentDto]] = None
    last_update_time: Optional[datetime] = Field(default=None, alias="lastUpdateTime")
    ignoring_reason: Optional[IssueIgnoringReasonDto] = Field(default=None, alias="ignoringReason")
    closing_location: Optional[IssueClosingLocationDto] = Field(default=None, alias="closingLocation")
    tags: Optional[List[IssueTagDto]] = None
    status_changed_note: Optional[StrictStr] = Field(default=None, alias="statusChangedNote")
    remediation_steps: Optional[List[StrictStr]] = Field(default=None, alias="remediationSteps")
    snoozed_type: Optional[SnoozedType] = Field(default=None, alias="snoozedType")
    snoozed_until: Optional[datetime] = Field(default=None, alias="snoozedUntil")
    ai_validation_result: Optional[AiValidationResult] = Field(default=None, alias="aiValidationResult")
    dast_confidence_level: Optional[DastConfidenceLevel] = Field(default=None, alias="dastConfidenceLevel")
    validity_status: Optional[SecretIssueValidityStatus] = Field(default=None, alias="validityStatus")
    verified_validation_url: Optional[StrictStr] = Field(default=None, alias="verifiedValidationUrl")
    dependency_fix_type: Optional[DependencyFixType] = Field(default=None, alias="dependencyFixType")
    __properties: ClassVar[List[str]] = ["id", "policyName", "title", "description", "relatedActionId", "origin", "ticketing", "productUnits", "detectedAt", "lastClosedAt", "status", "type", "severity", "policySeverity", "payload", "integration", "score", "epssScore", "assignedUser", "comments", "lastUpdateTime", "ignoringReason", "closingLocation", "tags", "statusChangedNote", "remediationSteps", "snoozedType", "snoozedUntil", "aiValidationResult", "dastConfidenceLevel", "validityStatus", "verifiedValidationUrl", "dependencyFixType"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of IssueDto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "payload",
            "assigned_user",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of origin
        if self.origin:
            _dict['origin'] = self.origin.to_dict()
        # override the default output from pydantic by calling `to_dict()` of ticketing
        if self.ticketing:
            _dict['ticketing'] = self.ticketing.to_dict()
        # override the default output from pydantic by calling `to_dict()` of integration
        if self.integration:
            _dict['integration'] = self.integration.to_dict()
        # override the default output from pydantic by calling `to_dict()` of assigned_user
        if self.assigned_user:
            _dict['assignedUser'] = self.assigned_user.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in comments (list)
        _items = []
        if self.comments:
            for _item_comments in self.comments:
                if _item_comments:
                    _items.append(_item_comments.to_dict())
            _dict['comments'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in tags (list)
        _items = []
        if self.tags:
            for _item_tags in self.tags:
                if _item_tags:
                    _items.append(_item_tags.to_dict())
            _dict['tags'] = _items
        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if policy_name (nullable) is None
        # and model_fields_set contains the field
        if self.policy_name is None and "policy_name" in self.model_fields_set:
            _dict['policyName'] = None

        # set to None if title (nullable) is None
        # and model_fields_set contains the field
        if self.title is None and "title" in self.model_fields_set:
            _dict['title'] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if related_action_id (nullable) is None
        # and model_fields_set contains the field
        if self.related_action_id is None and "related_action_id" in self.model_fields_set:
            _dict['relatedActionId'] = None

        # set to None if origin (nullable) is None
        # and model_fields_set contains the field
        if self.origin is None and "origin" in self.model_fields_set:
            _dict['origin'] = None

        # set to None if ticketing (nullable) is None
        # and model_fields_set contains the field
        if self.ticketing is None and "ticketing" in self.model_fields_set:
            _dict['ticketing'] = None

        # set to None if product_units (nullable) is None
        # and model_fields_set contains the field
        if self.product_units is None and "product_units" in self.model_fields_set:
            _dict['productUnits'] = None

        # set to None if last_closed_at (nullable) is None
        # and model_fields_set contains the field
        if self.last_closed_at is None and "last_closed_at" in self.model_fields_set:
            _dict['lastClosedAt'] = None

        # set to None if payload (nullable) is None
        # and model_fields_set contains the field
        if self.payload is None and "payload" in self.model_fields_set:
            _dict['payload'] = None

        # set to None if integration (nullable) is None
        # and model_fields_set contains the field
        if self.integration is None and "integration" in self.model_fields_set:
            _dict['integration'] = None

        # set to None if score (nullable) is None
        # and model_fields_set contains the field
        if self.score is None and "score" in self.model_fields_set:
            _dict['score'] = None

        # set to None if epss_score (nullable) is None
        # and model_fields_set contains the field
        if self.epss_score is None and "epss_score" in self.model_fields_set:
            _dict['epssScore'] = None

        # set to None if assigned_user (nullable) is None
        # and model_fields_set contains the field
        if self.assigned_user is None and "assigned_user" in self.model_fields_set:
            _dict['assignedUser'] = None

        # set to None if comments (nullable) is None
        # and model_fields_set contains the field
        if self.comments is None and "comments" in self.model_fields_set:
            _dict['comments'] = None

        # set to None if ignoring_reason (nullable) is None
        # and model_fields_set contains the field
        if self.ignoring_reason is None and "ignoring_reason" in self.model_fields_set:
            _dict['ignoringReason'] = None

        # set to None if closing_location (nullable) is None
        # and model_fields_set contains the field
        if self.closing_location is None and "closing_location" in self.model_fields_set:
            _dict['closingLocation'] = None

        # set to None if tags (nullable) is None
        # and model_fields_set contains the field
        if self.tags is None and "tags" in self.model_fields_set:
            _dict['tags'] = None

        # set to None if status_changed_note (nullable) is None
        # and model_fields_set contains the field
        if self.status_changed_note is None and "status_changed_note" in self.model_fields_set:
            _dict['statusChangedNote'] = None

        # set to None if remediation_steps (nullable) is None
        # and model_fields_set contains the field
        if self.remediation_steps is None and "remediation_steps" in self.model_fields_set:
            _dict['remediationSteps'] = None

        # set to None if snoozed_type (nullable) is None
        # and model_fields_set contains the field
        if self.snoozed_type is None and "snoozed_type" in self.model_fields_set:
            _dict['snoozedType'] = None

        # set to None if snoozed_until (nullable) is None
        # and model_fields_set contains the field
        if self.snoozed_until is None and "snoozed_until" in self.model_fields_set:
            _dict['snoozedUntil'] = None

        # set to None if ai_validation_result (nullable) is None
        # and model_fields_set contains the field
        if self.ai_validation_result is None and "ai_validation_result" in self.model_fields_set:
            _dict['aiValidationResult'] = None

        # set to None if verified_validation_url (nullable) is None
        # and model_fields_set contains the field
        if self.verified_validation_url is None and "verified_validation_url" in self.model_fields_set:
            _dict['verifiedValidationUrl'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of IssueDto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "policyName": obj.get("policyName"),
            "title": obj.get("title"),
            "description": obj.get("description"),
            "relatedActionId": obj.get("relatedActionId"),
            "origin": IssueOriginDto.from_dict(obj["origin"]) if obj.get("origin") is not None else None,
            "ticketing": IssueTicketingDto.from_dict(obj["ticketing"]) if obj.get("ticketing") is not None else None,
            "productUnits": obj.get("productUnits"),
            "detectedAt": obj.get("detectedAt"),
            "lastClosedAt": obj.get("lastClosedAt"),
            "status": obj.get("status"),
            "type": obj.get("type"),
            "severity": obj.get("severity"),
            "policySeverity": obj.get("policySeverity"),
            "payload": obj.get("payload"),
            "integration": IntegrationDto.from_dict(obj["integration"]) if obj.get("integration") is not None else None,
            "score": obj.get("score"),
            "epssScore": obj.get("epssScore"),
            "assignedUser": UserDto.from_dict(obj["assignedUser"]) if obj.get("assignedUser") is not None else None,
            "comments": [IssueCommentDto.from_dict(_item) for _item in obj["comments"]] if obj.get("comments") is not None else None,
            "lastUpdateTime": obj.get("lastUpdateTime"),
            "ignoringReason": obj.get("ignoringReason"),
            "closingLocation": obj.get("closingLocation"),
            "tags": [IssueTagDto.from_dict(_item) for _item in obj["tags"]] if obj.get("tags") is not None else None,
            "statusChangedNote": obj.get("statusChangedNote"),
            "remediationSteps": obj.get("remediationSteps"),
            "snoozedType": obj.get("snoozedType"),
            "snoozedUntil": obj.get("snoozedUntil"),
            "aiValidationResult": obj.get("aiValidationResult"),
            "dastConfidenceLevel": obj.get("dastConfidenceLevel"),
            "validityStatus": obj.get("validityStatus"),
            "verifiedValidationUrl": obj.get("verifiedValidationUrl"),
            "dependencyFixType": obj.get("dependencyFixType")
        })
        return _obj





# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class SdlcAssetGraphLinkDtoEvidences(BaseModel):
    """
    SdlcAssetGraphLinkDtoEvidences
    """ # noqa: E501
    unknown: Optional[List[StrictStr]] = Field(default=None, alias="Unknown")
    file: Optional[List[StrictStr]] = Field(default=None, alias="File")
    webhook: Optional[List[StrictStr]] = Field(default=None, alias="Webhook")
    config: Optional[List[StrictStr]] = Field(default=None, alias="Config")
    job_config: Optional[List[StrictStr]] = Field(default=None, alias="JobConfig")
    third_party_app: Optional[List[StrictStr]] = Field(default=None, alias="ThirdPartyApp")
    organization_webhook: Optional[List[StrictStr]] = Field(default=None, alias="OrganizationWebhook")
    correlated_artifact: Optional[List[StrictStr]] = Field(default=None, alias="CorrelatedArtifact")
    git_lab_repository_to_registry: Optional[List[StrictStr]] = Field(default=None, alias="GitLabRepositoryToRegistry")
    manual_correlation: Optional[List[StrictStr]] = Field(default=None, alias="ManualCorrelation")
    llm_based_correlation: Optional[List[StrictStr]] = Field(default=None, alias="LlmBasedCorrelation")
    __properties: ClassVar[List[str]] = ["Unknown", "File", "Webhook", "Config", "JobConfig", "ThirdPartyApp", "OrganizationWebhook", "CorrelatedArtifact", "GitLabRepositoryToRegistry", "ManualCorrelation", "LlmBasedCorrelation"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SdlcAssetGraphLinkDtoEvidences from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SdlcAssetGraphLinkDtoEvidences from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "Unknown": obj.get("Unknown"),
            "File": obj.get("File"),
            "Webhook": obj.get("Webhook"),
            "Config": obj.get("Config"),
            "JobConfig": obj.get("JobConfig"),
            "ThirdPartyApp": obj.get("ThirdPartyApp"),
            "OrganizationWebhook": obj.get("OrganizationWebhook"),
            "CorrelatedArtifact": obj.get("CorrelatedArtifact"),
            "GitLabRepositoryToRegistry": obj.get("GitLabRepositoryToRegistry"),
            "ManualCorrelation": obj.get("ManualCorrelation"),
            "LlmBasedCorrelation": obj.get("LlmBasedCorrelation")
        })
        return _obj


